$black: #313131;
$black-dark: #1b1b1b;
$black-darker: #000000;

$blue: #34aab5;
$blue-light: #36b0bb;
$blue-medium: #195156;
$blue-dark: #144145;
$blue-darker: #4F1109;

$gray: #707070;
$gray-dark: #818181;
$gray-medium: #d5d5d5;
$gray-light: #b5b5b5;
$gray-lighter: #f0f0f0;

$white: #ffffff;

@import 'default';