<?php

// jCart v1.3
// http://conceptlogic.com/jcart/

// By default, this file returns the $config array for use with PHP scripts
// If requested via Ajax, the array is encoded as JSON and echoed out to the browser

// Don't edit here, edit config.php
include_once('config.php');

// Use default values for any settings that have been left empty
if (!$config['currencyCode']) $config['currencyCode']                     = 'BRL';
if (!$config['text']['cartTitle']) $config['text']['cartTitle']           = 'Carrinho de compra';
if (!$config['text']['singleItem']) $config['text']['singleItem']         = 'Item';
if (!$config['text']['multipleItems']) $config['text']['multipleItems']   = 'Itens';
if (!$config['text']['subtotal']) $config['text']['subtotal']             = 'Subtotal';
if (!$config['text']['update']) $config['text']['update']                 = 'atualizar';
if (!$config['text']['checkout']) $config['text']['checkout']             = 'checkout';
if (!$config['text']['checkoutPaypal']) $config['text']['checkoutPaypal'] = 'Checkout com pagseguro';
if (!$config['text']['removeLink']) $config['text']['removeLink']         = 'remover';
if (!$config['text']['emptyButton']) $config['text']['emptyButton']       = 'esvaziar';
if (!$config['text']['emptyMessage']) $config['text']['emptyMessage']     = 'Seu carrinho está vazio!';
if (!$config['text']['itemAdded']) $config['text']['itemAdded']           = 'Item adicionado!';
if (!$config['text']['priceError']) $config['text']['priceError']         = 'Inválido formato de preço!';
if (!$config['text']['quantityError']) $config['text']['quantityError']   = 'A quantidade precisa ser em números!';
if (!$config['text']['checkoutError']) $config['text']['checkoutError']   = 'Seu pedido não pode ser processado!';

if ($_GET['ajax'] == 'true') {
	header('Content-type: application/json; charset=utf-8');
	echo json_encode($config);
}
?>