<h1 class="page-header">
<a href="index.php">Home</a> << Disciplinas disponíveis "
<?php
	$y = 0;
	$c = new Control();
	$arr = $c->Controle_concurso($_GET['id'], ID);
	for ($i = 0; $i < 1; $i++){
		echo "Banco do Brasil";
	}
?>
"
</h1>
<div class="properties-grid">
	<div class="row">		
		<?php
			$y = 0;
			$arr = $c->Controle_VConcurso($_GET['id'], ID);
			for ($i = 0; $i < count($arr); $i++){
				if($y == 3){
       				echo '</div><br><div class="row">';
       				$y = 0;
    			}
    			$y++;				
		?>
		<div class="property span3">
			<div class="image">
				<div class="content">
					<a href="detalhe.php?id=<?=$arr[$i]->id['id']?>"></a>
					<img src="<?=$arr[$i]->capa['capa']?>" alt="">
				</div><!-- /.content -->
				<div class="price">R$ <?=$arr[$i]->valor['valor']?></div><!-- /.price -->
				<div class="reduced"><?=$arr[$i]->pacote['pacote']?'Pacote':'Avulso'?></div><!-- /.reduced -->
			</div><!-- /.image -->	
			<div class="title">
				<h2><a href="detalhe.php?id=<?=$arr[$i]->id['id']?>"><?=$arr[$i]->nome['nome']?></a></h2>
			</div><!-- /.title -->	
			<div class="location">
			<?php
				if($arr[$i]->pacote['pacote'] == false){
					$arre = $c->Venda_many($arr[$i]->id['id']);
					for ($j = 0; $j < count($arre); $j++){
			        	echo $arre[$j]->concursoNome['concursoNome'];
					}
				}else{
			        	echo "Mais de uma disciplina";					
				}
			?>				
			</div><!-- /.location -->
		</div><!-- /.property -->
		<?php
			}
		?>		
	</div><!-- /.row -->		
</div><!-- /.properties-grid -->



