/************************************************************
 * Body
 ***********************************************************/
$body-background-color: $gray-lighter;
$body-text-color: $gray;
$body-link-color: $blue;
$body-heading-color: $blue-dark;

/************************************************************
 * Header
 ***********************************************************/
$header-background-color: $white;
$header-brand-color: $blue-dark;
$header-slogan-color: $gray-light;
$header-slogan-border-color: $gray-lighter;
$header-info-color: $gray;

$breadcrumb-background-color: $blue-dark;
$breadcrumb-link-color: $blue;
$breadcrumb-text-color: $white;

/************************************************************
 * Forms
 ***********************************************************/
$forms-slider-background-color: $blue-dark;
$forms-chosen-selected-color: $white;
$forms-chosen-selected-background-color: $blue;
$forms-chosen-search-border-color: $gray;
$forms-chosen-background-color: $white;
$forms-chosen-border-color: $gray-medium;

$forms-submit-color: $white;
$forms-submit-background-color: $blue-light;
$forms-textarea-color: $gray;
$forms-textarea-border-color: $gray-medium;
$forms-file-select-background-color: $blue-dark;
$forms-input-append-border-color: $gray-medium;

/************************************************************
 * Elements
 ***********************************************************/
$elements-sidebar-h2-color: $gray;

/************************************************************
 * Navigation
 ***********************************************************/
$navigation-link-border-color: $blue;
$navigation-link-color: $black;
$navigation-link-color-hover: $blue;
$navigation-link-hover-background-color: $blue-dark;
$navigation-sub-background-color: $blue-dark;
$navigation-sub-link-color: $white;
$navigation-background-color: $blue-dark;
$navigation-link-color: $black;
$navigation-language-background-color: $white;

/************************************************************
 * Properties
 ***********************************************************/
$properties-grid-title-color: $blue;
$properties-grid-background-color: $white;
$properties-grid-price-background-color: $white;
$properties-grid-price-color: $black;
$properties-grid-reduced-background-color: $black;
$properties-grid-reduced-color: $white;
$properties-grid-area-color: $black;
$properties-grid-bedrooms-color: $black;
$properties-grid-bathrooms-color: $black;

$properties-rows-background-color: $white;
$properties-rows-h2-color: $blue;
$properties-rows-price-color: $black;
$properties-rows-location-color: $gray;

$properties-widget-background-color: $white;
$properties-widget-price-color: $blue-dark;

$properties-detail-background-color: $white;
$properties-detail-overview-border-color: $gray-light;

$properties-filter-horizontal-background-color: $white;
$properties-filter-horizontal-label-color: $black-dark;

$properties-filter-vertical-background-color: $blue-light;
$properties-filter-vertical-label-color: $white;
$properties-filter-vertical-button-background-color: $blue-dark;

/************************************************************
 * Agents
 ***********************************************************/
$agents-widget-background-color: $white;
$agents-widget-name-color: $black;

/************************************************************
 * Carousel
 ***********************************************************/
$carousel-background-color: $blue-dark;
$carousel-button-background-color: $blue;
$carousel-item-title-color: $blue-dark;
$carousel-item-background-color: $white;
$carousel-item-price-color: $black;
$carousel-item-area-color: $black;
$carousel-item-bedrooms-color: $black;
$carousel-item-bathrooms-color: $black;

/************************************************************
 * Partners
 ***********************************************************/
$partners-background-color: $white;

/************************************************************
 * Features
 ***********************************************************/
$features-title-color: $black;

/************************************************************
 * Login register
 ***********************************************************/
$login-register-h3-color: $black-dark;

/************************************************************
 * Pricing
 ***********************************************************/
$pricing-background-color: $white;
$pricing-h2-color: $blue-light;
$pricing-h3-color: $black-dark;
$pricing-h4-color: $gray-dark;
$pricing-unimportant-color: $gray-light;
$pricing-button-background-color: $blue-light;
$pricing-boxed-h2-color: $white;
$pricing-boxed-h2-background-color: $blue-light;
$pricing-boxed-h3-color: $blue-dark;
$pricing-boxed-promoted-h2-background-color: $blue-dark;
$pricing-boxed-promoted-border-color: $blue-dark;

/************************************************************
 * Slider
 ***********************************************************/
$slider-background-color: $blue-dark;
$slider-h2-color: $blue;
$slider-navigation-background-color: $white;
$slider-navigation-active-background-color: $blue-dark;

/************************************************************
 * Map
 ***********************************************************/
$map-infobox-background-color: $white;
$map-infobox-area-color: $black;
$map-infobox-price-color: $black;

/************************************************************
 * Bottom
 ***********************************************************/
$bottom-background-color: $white;
$bottom-circle-background-color: $gray-lighter;
$bottom-circle-border-color: $gray-lighter;
$bottom-circle-background-color-hover: $blue-dark;
$bottom-circle-border-color-hover: $blue;
$bottom-circle-title-color: $blue-dark;

/************************************************************
 * Footer
 ***********************************************************/
$footer-top-color: $white;
$footer-top-background-color: $blue-medium;
$footer-top-header-color: $blue;
$footer-top-link-color: $white;
$footer-top-link-color-hover: $blue;
$footer-top-bullet-color: $blue;
$footer-top-th-color: $blue;
$footer-top-widget-properties-background-color: $blue-dark;
$footer-top-widget-properties-price-color: $white;
$footer-bottom-background-color: $blue-dark;