<?php

define("ID", $xml->id);
define("NOME", $xml->nome);
define("LOGO", $xml->logo);
define("SITE", $xml->site);
define("FOLDER", $xml->folder);
//define("TEXTCADASTRO", $xml->folder);
//define("TEXTCONTATO", $xml->folder);
define("PAGSEGURO", $xml->pagseguro);
define("TOKEN", $xml->token);
?>
