.sidebar {
  h2 { color: $elements-sidebar-h2-color; }
  .widget {
    &.last { margin-bottom: 0px; }
  }
}

.ad {
  .content { text-align: center; }
}

.widget {
  &.contact {
    .content { @include shadow(); background-color: $white; padding: 20px;
      form { margin: 0px;
        input[type=text], textarea { @include box-sizing(border-box); width: 100%; }
        input[type=text] { height: 32px; }
      }
    }
  }
}


iframe { border: 0px; width: 100%;
  &.map { @include box-sizing(border-box); @include shadow; background-color: $white; margin: 0px 0px 20px 0px; padding: 20px; width: 100% !important; }
}


.tabs { border: 0px; margin: 15px 0px 0px 0px;
  li { border: 0px;
    a { @include border-radius(0px); background-color: $gray-lighter; border: 0px !important; color: $gray; font-size: 16px;
      &:hover { border: 0px; }
    }
    &.active { background-color: $white;
      a { color: $blue-dark;
        &:hover { color: $blue-dark; }
      }
    }
  }
}

.tab-content { @include shadow; background-color: $white; padding: 20px; }

.accordion-group { border: 0px; border-bottom: 1px solid #fff;
  .accordion-heading { @include border-radius(0px);
    .sign { background-color: $black-dark; background-image: url('../img/icons/faq-plus.png'); background-position: center center; background-repeat: no-repeat; background-size: 8px 8px; display: inline-block; height: 30px; margin-right: 30px; vertical-align: middle; width: 30px;
      @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
        background-image: url('../img/icons/faq-plus@2x.png');
      }
    }
    a { color: $black-dark; font-size: 18px; line-height: 30px; padding-left: 0px; padding-right: 0px;
      &:hover { text-decoration: none; }
      &.active {
        .sign { background-color: $blue; background-image: url('../img/icons/faq-minus.png'); background-size: 8px 2px;
          @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
            background-image: url('../img/icons/faq-minus@2x.png');
          }
        }
      }
    }
  }
  &:last-child { border-bottom: 0px; }
}

.accordion-body {
  .accordion-inner { border: 0px; padding: 20px 0px; }
}

.box { @include shadow; background-color: $white; padding: 20px;
  .office { background-image: url('../img/icons/phone-gray.png'); background-position: left center; background-repeat: no-repeat; background-size: 20px 20px; line-height: 26px; margin-bottom: 5px; padding-left: 30px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/icons/phone-gray@2x.png');
    }
  }
  .phone { background-image: url('../img/icons/cell-phone-gray.png'); background-position: 4px center; background-repeat: no-repeat; background-size: 12px 20px; line-height: 26px; margin-bottom: 5px; padding-left: 30px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/icons/cell-phone-gray@2x.png');
    }
  }
  .email { background-image: url('../img/icons/mail-gray.png'); background-position: 1px center; background-repeat: no-repeat; background-size: 17px 11px; line-height: 26px; padding-left: 30px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/icons/mail-gray@2x.png');
    }
  }
}

.pagination {
  ul { @include border-radius(0px); @include box-shadow(none); margin-bottom: 0px; margin-top: 30px;
    li {
      a { @include border-radius(0px); @include box-shadow(0px 1px 1px rgba(1, 1, 1, .25)); background-color: #fff; border: 0px; margin: 0px 5px; padding: 7px 14px;
        &:hover { background-color: $blue; color: $white; }
      }
      &.active {
        a { background-color: $blue-light; color: $white; }
      }
      &:first-child, &:last-child {
        a { @include border-radius(0px); }
      }
    }
  }
}