<?php

class Venda{

	public $id;
	public $nome;
	public $valor;
	public $capa;
	public $cliente_idcliente;
	public $cursoNome;
	public $concursoNome;	
	public $date_in;	
	public $date_out;			
	public $descricao;
	public $adicional;	
	public $pacote;		
	
	protected function setid($id){
		$this->id = $id;
	}

	protected function setnome($nome){
		$this->nome = $nome;
	}

	protected function setvalor($valor){
		$this->valor = $valor;
	}

	protected function setcapa($capa){
		$this->capa = $capa;
	}
	
	protected function setcliente_idcliente($cliente_idcliente){
		$this->cliente_idcliente = $cliente_idcliente;
	}	
	
	protected function setcursoNome($cursoNome){
		$this->cursoNome = $cursoNome;
	}	

	protected function setconcursoNome($concursoNome){
		$this->concursoNome = $concursoNome;
	}	
	
	protected function setdate_in($date_in){
		$this->date_in = $date_in;
	}

	protected function setdate_out($date_out){
		$this->date_out = $date_out;
	}	

	protected function setdescricao($descricao){
		$this->descricao = $descricao;
	}		

	protected function setadicional($adicional){
		$this->adicional = $adicional;
	}	
	
	protected function setpacote($pacote){
		$this->pacote = $pacote;
	}		
	
	public function all($id, $cliente){

		$arr = array();	
			
		if($id == ''){
			$sql = "SELECT * FROM `venda` WHERE `venda`.`cliente_idcliente`=$cliente AND `pacote`=1;";
			$vai = new MySQLDB();
			$result = $vai->executeQuery($sql);
		}else{
			$sql = "SELECT * FROM `venda` WHERE `venda`.`id`=$id;";
			$vai = new MySQLDB();
			$result = $vai->executeQuery($sql);
		}
		while($dados = mysql_fetch_array($result)){
			$cliente = new Venda();
			$cliente->setid(array('id' => $dados['id']));
			$cliente->setnome(array('nome' => $dados['nome']));
			$cliente->setvalor(array('valor' => $dados['valor']));		
			$cliente->setcapa(array('capa' => $dados['capa']));
			$cliente->setcliente_idcliente(array('cliente_idcliente' => $dados['cliente_idcliente']));	
			$cliente->setdate_in(array('date_in' => $dados['date_in']));
			$cliente->setdate_out(array('date_out' => $dados['date_out']));
			$cliente->setdescricao(array('descricao' => $dados['descricao']));
			$cliente->setadicional(array('adicional' => $dados['adicional']));					
			$cliente->setpacote(array('pacote' => $dados['pacote']));								
			$arr[] = $cliente;
		}
		return $arr;
	}	

	public function allMany($id){

		$arr = array();	
			
		$sql = "SELECT `curso`.`idcurso` AS `id`, `curso`.`nome` AS `cursoNome`, `curso`.`valor`, `concurso`.`nome` AS `concursoNome` FROM `curso`
			INNER JOIN `concurso` ON `concurso`.`idconcurso`=`curso`.`concurso_idconcurso`
			INNER JOIN `venda_curso` ON `venda_curso`.`curso_id`=`curso`.`idcurso`
			WHERE `venda_curso`.`venda_id`=$id;";
		$vai = new MySQLDB();
		$result = $vai->executeQuery($sql);

		while($dados = mysql_fetch_array($result)){
			$cliente = new Venda();
			$cliente->setid(array('id' => $dados['id']));			
			$cliente->setvalor(array('valor' => $dados['valor']));						
			$cliente->setcursoNome(array('cursoNome' => $dados['cursoNome']));		
			$cliente->setconcursoNome(array('concursoNome' => $dados['concursoNome']));					
			$arr[] = $cliente;
		}
		return $arr;
	}	

	public function allNova($id, $cliente){

		$arr = array();	
			
		$sql = "SELECT * FROM `venda` WHERE `venda`.`cliente_idcliente`=$cliente ORDER BY `venda`.`id` DESC LIMIT 0,5;";
		$vai = new MySQLDB();
		$result = $vai->executeQuery($sql);

		while($dados = mysql_fetch_array($result)){
			$cliente = new Venda();
			$cliente->setid(array('id' => $dados['id']));
			$cliente->setnome(array('nome' => $dados['nome']));
			$cliente->setvalor(array('valor' => $dados['valor']));		
			$cliente->setcapa(array('capa' => $dados['capa']));
			$cliente->setcliente_idcliente(array('cliente_idcliente' => $dados['cliente_idcliente']));	
			$cliente->setdate_in(array('date_in' => $dados['date_in']));
			$cliente->setdate_out(array('date_out' => $dados['date_out']));
			$cliente->setdescricao(array('descricao' => $dados['descricao']));
			$cliente->setadicional(array('adicional' => $dados['adicional']));					
			$cliente->setpacote(array('pacote' => $dados['pacote']));								
			$arr[] = $cliente;
		}
		return $arr;
	}	
	
	public function allConcurso($id, $cliente){

		$arr = array();	
			
		$sql = "SELECT * FROM `venda`
				INNER JOIN `venda_curso` ON `venda_curso`.`venda_id`=`venda`.`id`
				INNER JOIN `curso` ON `venda_curso`.`curso_id`=`curso`.`idcurso`
				WHERE `curso`.`concurso_idconcurso`=$id
				AND `curso`.`cliente_idcliente`=$cliente;";
		$vai = new MySQLDB();
		$result = $vai->executeQuery($sql);

		while($dados = mysql_fetch_array($result)){
			$cliente = new Venda();
			$cliente->setid(array('id' => $dados['id']));
			$cliente->setnome(array('nome' => $dados['nome']));
			$cliente->setvalor(array('valor' => $dados['valor']));		
			$cliente->setcapa(array('capa' => $dados['capa']));
			$cliente->setcliente_idcliente(array('cliente_idcliente' => $dados['cliente_idcliente']));	
			$cliente->setdate_in(array('date_in' => $dados['date_in']));
			$cliente->setdate_out(array('date_out' => $dados['date_out']));
			$cliente->setdescricao(array('descricao' => $dados['descricao']));
			$cliente->setadicional(array('adicional' => $dados['adicional']));					
			$cliente->setpacote(array('pacote' => $dados['pacote']));				
			$arr[] = $cliente;
		}
		return $arr;
	}	
	
}

?>