<div class="widget our-agents">
	<div class="title">
		<h2>Meu carrinho</h2>
	</div><!-- /.title -->
	<div class="content">
		<div id="jcart"><?php $jcart->display_cart();?></div>
	</div><!-- /.content -->
</div><!-- /.our-agents -->