	<div class="carousel-wrapper">
		<div class="carousel">
		    <h2 class="page-header">Cursos em destaque</h2>
		
		    <div class="content">
		        <a class="carousel-prev" href="detail.html">Previous</a>
		        <a class="carousel-next" href="detail.html">Next</a>
		        <ul>
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-1.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-2.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-3.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-4.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-5.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-6.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-1.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-2.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		            <li>
		                <div class="image">
		                    <a href="detalhe.php"></a>
		                    <img src="assets/img/tmp/property-small-3.png" alt="">
		                </div><!-- /.image -->
		                <div class="title">
		                    <h3><a href="detalhe.php">27523 Pacific Coast</a></h3>
		                </div><!-- /.title -->
		                <div class="location">Palo Alto CA</div><!-- /.location-->
		                <div class="price">€2 300 000</div><!-- .price -->
		                <div class="area">
		                    <span class="key">Area:</span>
		                    <span class="value">750m<sup>2</sup></span>
		                </div><!-- /.area -->
		                <div class="bathrooms"><div class="inner">3</div></div><!-- /.bathrooms -->
		                <div class="bedrooms"><div class="inner">3</div></div><!-- /.bedrooms -->
		            </li>
		
		        </ul>
		    </div><!-- /.content -->
		</div><!-- /.carousel -->    
	</div>	    