<?php

$xml=simplexml_load_file("config/config.xml");
include('config/controller.php');
include('config/config.php');
include_once('jcart/jcart.php');
include('include/head.php');

if(isset($_SESSION['nomeAluno'])){
?>
<body>
<div id="wrapper-outer" >
    <div id="wrapper">
        <div id="wrapper-inner">
		<?php
			include('include/header.php');

			include('include/menu.php');
		?>
		<div id="content">
			<?php
			//include('include/carousel.php');
			?>		
			<div class="container">
    			<div id="main">
        			<div class="row">
            			<div class="span9">
							<h1 class="page-header">Compra efetuada com sucesso</h1>
							<div class="properties-grid">
								<div class="row">		
									<div id="wrapper">
										<div id="sidebar">
										</div>
										<div id="content">
											<?php
											if($_REQUEST['finalizado'] == 1){
											?>	
											<p style="margin: 30px; font-size: 20px;">Esta compra já foi efetuada! Aguarde a liberação do curso!</p>
											<p style="margin: 30px; font-size: 20px;">Acesse o <a href="http://joao.circletecnologia.com.br/aluno">painel do aluno</a></p>											
											<?php
											}else{
											?>		
											<p style="margin: 30px; font-size: 20px;">Sua compra foi efetuada com sucesso! Aguarde a liberação do curso!</p>
											<p style="margin: 30px; font-size: 20px;">Acesse o <a href="http://joao.circletecnologia.com.br/aluno">painel do aluno</a></p>
											<?php
											}
											?>																							
										</div>
							
										<div class="clear"></div>
									</div>
								</div><!-- /.row -->		
							</div><!-- /.properties-grid -->
            			</div>
			            <div class="sidebar span3">
			                <div class="hidden-tablet">
								<?php
								$c = new Control();
								include('include/novo.php');
								?>
			                </div>
			            </div>
        			</div>
				</div>
			</div>
		</div>
	</div>
	<?php
	include('include/footer.php');
	include('include/configuracao.php');
	?>
<script type="text/javascript" src="assets/js/jquery.js"></script>
<script type="text/javascript" src="assets/js/jquery.ezmark.js"></script>
<script type="text/javascript" src="assets/js/jquery.currency.js"></script>
<script type="text/javascript" src="assets/js/jquery.cookie.js"></script>
<script type="text/javascript" src="assets/js/retina.js"></script>
<script type="text/javascript" src="assets/js/bootstrap.min.js"></script>
<script type="text/javascript" src="assets/js/carousel.js"></script>
<script type="text/javascript" src="assets/libraries/jquery-ui-1.10.2.custom/js/jquery-ui-1.10.2.custom.min.js"></script>
<script type="text/javascript" src="assets/libraries/chosen/chosen.jquery.min.js"></script>
<script type="text/javascript" src="assets/libraries/iosslider/_src/jquery.iosslider.min.js"></script>
<script type="text/javascript" src="assets/libraries/bootstrap-fileupload/bootstrap-fileupload.js"></script>
<script type="text/javascript" src="assets/js/realia.js"></script>
<script type="text/javascript" src="jcart/js/jcart.js"></script>
</body>
</html>
<?php
}else{
	header ("Location: login.php");	
}
