.ez-hide { opacity: 0; filter:alpha(opacity=0); }
.ez-checkbox { background-image: url('../img/checkbox.png'); background-position: center center; background-repeat: no-repeat; background-size: 20px 20px; display:inline-block; float: left; height: 20px; margin-bottom: -5px; margin-right: 10px; width: 20px;
    input { height: 20px; margin: 0px; width: 20px;  }
	@media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
		background-image: url('../img/checkbox@2x.png');
	}
}
.ez-radio { background-image: url('../img/radio.png'); background-position: center center; background-repeat: no-repeat; background-size: 21px 21px; display:inline-block; float: left;
	@media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
		background-image: url('../img/radio@2x.png');
	}
}
.ez-checked { background-image: url('../img/checkbox-open.png'); 
	@media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
		background-image: url('../img/checkbox-open@2x.png');
	}
}
.ez-selected { background-image: url('../img/radio-open.png'); 
	@media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
		background-image: url('../img/radio-open@2x.png');
	}
}