            <!-- NAVIGATION -->
            <div id="navigation">
                <div class="container">
                    <div class="navigation-wrapper">
                        <div class="navigation clearfix-normal">

                            <ul class="nav">
                                <li><a href="aulas.php">Aulas</a></li>
                                <li><a href="checkout.php">Carrinho</a></li>
                                <li><a href="contato.php">Contato</a></li>                                
                            </ul><!-- /.nav -->

                            <form method="get" class="site-search" action="?">
                                <div class="input-append">
                                    <input title="Faça uma pesquisa." class="search-query span2 form-text" placeholder="Pesquisa" type="text" name="">
                                    <button type="submit" class="btn"><i class="icon-search"></i></button>
                                </div><!-- /.input-append -->
                            </form><!-- /.site-search -->
                        </div><!-- /.navigation -->
                    </div><!-- /.navigation-wrapper -->
                </div><!-- /.container -->
            </div><!-- /.navigation -->