<?php

class Concurso{

	public $idconcurso;
	public $nome;
	public $descricao;
	public $remuneracao;
	public $vagas;
	public $cliente_idcliente;	

	protected function setidconcurso($idconcurso){
		$this->idconcurso = $idconcurso;
	}

	protected function setnome($nome){
		$this->nome = $nome;
	}

	protected function setdescricao($descricao){
		$this->descricao = $descricao;
	}

	protected function setremuneracao($remuneracao){
		$this->remuneracao = $remuneracao;
	}

	protected function setvagas($vagas){
		$this->vagas = $vagas;
	}

	protected function setcliente_idcliente($cliente_idcliente){
		$this->cliente_idcliente = $cliente_idcliente;
	}		

	public function all($id, $cliente){

		$arr = array();	
			
		$sql = "SELECT * FROM `concurso` WHERE `cliente_idcliente`=$cliente;";
		$vai = new MySQLDB();
		$result = $vai->executeQuery($sql);
		
		while($dados = mysql_fetch_array($result)){
			$cliente = new Concurso();
			$cliente->setidconcurso(array('idconcurso' => $dados['idconcurso']));
			$cliente->setnome(array('nome' => $dados['nome']));
			$cliente->setdescricao(array('descricao' => $dados['descricao']));
			$cliente->setremuneracao(array('remuneracao' => $dados['remuneracao']));
			$cliente->setvagas(array('vagas' => $dados['vagas']));
			$cliente->setcliente_idcliente(array('cliente_idcliente' => $dados['cliente_idcliente']));		
			$arr[] = $cliente;
		}
		return $arr;
	}		
}

?>