            <!-- BREADCRUMB -->
            <div class="breadcrumb-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="span12">
                            <ul class="breadcrumb pull-left">
                                <li><a href="index.php">Home</a></li>
                            </ul><!-- /.breadcrumb -->

                            <div class="account pull-right">
                                <ul class="nav nav-pills">
                                	<?php
                                	if(isset($_SESSION['nomeAluno'])){
                                	?>
                                	<li><a>Olá <?=$_SESSION['nomeAluno']?></a></li>
                                    <li><a href="logout.php">Logout</a></li>
                                    <?php
                                	}else{
                                	?>
                                    <li><a href="login.php">Login</a></li>                                	
                                    <?php
                                	}
                                	?>                                	
                                </ul>
                            </div>
                        </div><!-- /.span12 -->
                    </div><!-- /.row -->
                </div><!-- /.container -->
            </div><!-- /.breadcrumb-wrapper -->
			<!-- HEADER -->
            <div id="header-wrapper">
                <div id="header">
                    <div id="header-inner">
                        <div class="container">
                            <div class="navbar">
                                <div class="navbar-inner">
                                    <div class="row">
                                        <div class="logo-wrapper span4">
                                            <a href="#nav" class="hidden-desktop" id="btn-nav">Toggle navigation</a>

                                            <div class="logo">
                                                <a href="index.php" title="Home">
                                                    <img src="<?=LOGO?>" alt="Home" style="height: 80px;">
                                                </a>
                                            </div><!-- /.logo -->

                                        </div><!-- /.logo-wrapper -->

                                        <div class="info">

                                        </div><!-- /.info -->
	                                	<?php
	                                	if(isset($_SESSION['nomeAluno'])){
	                                	?>
										<a class="btn btn-primary btn-large list-your-property arrow-right" href="http://joao.circletecnologia.com.br/aluno">Entrar no sistema</a>	                                	
	                                    <?php
	                                	}else{
	                                	?>
	                                	<a class="btn btn-primary btn-large list-your-property arrow-right" href="cadastro.php">Cadastre-se</a>
	                                    <?php
	                                	}
	                                	?>  	                                	                                        
                                    </div><!-- /.row -->
                                </div><!-- /.navbar-inner -->
                            </div><!-- /.navbar -->
                        </div><!-- /.container -->
                    </div><!-- /#header-inner -->
                </div><!-- /#header -->
            </div><!-- /#header-wrapper -->
