<h1 class="page-header"><a href="index.php">Home</a> << Cursos disponíveis</h1>
<div class="properties-grid">
	<div class="row">		
		<?php
			$y = 0;
			$c = new Control();
			$arr = $c->Controle_concurso($id = null, ID);
			for ($i = 0; $i < count($arr); $i++){
				if($y == 3){
       				echo '</div><br><div class="row">';
       				$y = 0;
    			}
    			$y++;				
		?>
		<div class="property span3">
			<a href="curso.php?id=<?=$arr[$i]->idconcurso['idconcurso']?>">
				<div class="title">
					<table align="center">
						<tr>
							<td>
								<h2><a href="curso.php?id=<?=$arr[$i]->idconcurso['idconcurso']?>"><?=$arr[$i]->nome['nome']?></a></h2>
							</td>
						</tr>
					</table>		
				</div><!-- /.title -->
			</a>	
		</div><!-- /.property -->
		<?php
			}
		?>		
	</div><!-- /.row -->		
</div><!-- /.properties-grid -->



