<?php

class Compra{

	public $id;
	public $data;
	public $modo_pag;
	public $valor;
	public $status;
	public $aluno_idaluno;	
	public $notification_id;	
	
	protected function setid($id){
		$this->id = $id;
	}

	protected function setdata($data){
		$this->data = $data;
	}

	protected function setmodo_pag($modo_pag){
		$this->modo_pag = $modo_pag;
	}

	protected function setvalor($valor){
		$this->valor = $valor;
	}

	protected function setstatus($status){
		$this->status = $status;
	}

	protected function setaluno_idaluno($aluno_idaluno){
		$this->aluno_idaluno = $aluno_idaluno;
	}	

	protected function setnotification_id($notification_id){
		$this->notification_id = $notification_id;
	}		
	
	/*
	public function all($id, $cliente){

		$arr = array();	
			
		$sql = "SELECT * FROM `compra` WHERE `cliente_idcliente` = $id;";
		$vai = new MySQLDB();
		$result = $vai->executeQuery($sql);
		
		while($dados = mysql_fetch_array($result)){
			$cliente = new Compra();
			$cliente->setid(array('id' => $dados['id']));
			$cliente->setdata();
			$cliente->modo_pag();
			$cliente->valor();
			$cliente->status();
			$cliente->aluno_idaluno();
			$arr[] = $cliente;
		}
		return $arr;
	}	
	*/
	
	
	public function Cad($data, $modo_pag, $valor, $status, $aluno_idaluno, $notification_id, $itens){

		$vai = new MySQLDB();
		
		$consulta = "SELECT `notification_id` FROM `compra` WHERE `notification_id`='$notification_id';";
		$result = $vai->ExecuteQuery($consulta);		
		
		while ($rows = mysql_fetch_object($result)) {
			$notify = $rows->notification_id;
		}
		
		if($notify){
			header('Location: sucesso.php?finalizado=1');
		}
				
		$sql = "INSERT INTO `compra` (`data`, `modo_pag`, `valor`, `status`, `aluno_idaluno`, `notification_id`) VALUES ('".substr($data, 0, -19)."', '$modo_pag', '$valor', '$status', $aluno_idaluno, '$notification_id');";
		$vai->executeQuery($sql);

		$compra = mysql_insert_id();
		
		foreach($itens as $key => $item) {  
			$query = "INSERT INTO `compra_curso` (`venda_id`, `nome`, `compra_id`) VALUES (".$item->getId().", '".$item->getDescription()."', ".$compra.");";
			$vai->executeQuery($query);	
			
			if($status == "PAID"){
				$data = date('Y-m-d');
				$sql = "INSERT INTO `aluno_venda` (`aluno_id`,`venda_id`, `liberacao`) 
						VALUES ($aluno_idaluno, ".$item->getId().", '$data');";
				$vai->executeQuery($sql);			
			}
		}

		header('Location: sucesso.php');	
		
	}		
	
}

?>