<?php

class Contato {
	
	public $id_contato;
	public $assunto;
	public $cliente_idcliente;
	public $texto;	
	public $novo;							
	public $type;								
	public $nome;								
	public $email;										
	
		
	protected function setid_contato($id_contato){
		$this->id_contato = $id_contato;
	}	
	
	protected function setassunto($assunto){
		$this->assunto = $assunto;
	}

	protected function settexto($texto){
		$this->texto = $texto;
	}

	protected function setcliente_idcliente($cliente_idcliente){
		$this->cliente_idcliente = $cliente_idcliente;
	}	
	
	protected function setnovo($novo){
		$this->novo = $novo;
	}	
	
	protected function settype($type){
		$this->type = $type;
	}		

	protected function setnome($nome){
		$this->nome = $nome;
	}

	protected function setemail($email){
		$this->email = $email;
	}	
		
	public function intoContato($nome, $email, $assunto, $mensagem, $cliente){
	   
		$sql = "INSERT INTO `contato` (`assunto`, `cliente_idcliente`, `novo`, `texto`, `type`, `nome`, `email`) VALUES ('$assunto', $cliente, 1, '$mensagem', 1, '$nome', '$email');";
		$vai = new MySQLDB(); 
		$vai->ExecuteQuery($sql);
		header ("Location: contato.php?vi=send&nome=$nome");
	}	

}

?>