<?php

// jCart v1.3
// http://conceptlogic.com/jcart/

// Do NOT store any sensitive info in this file!!!
// It's loaded into the browser as plain text via Ajax


////////////////////////////////////////////////////////////////////////////////
// REQUIRED SETTINGS

// Path to your jcart files
$config['jcartPath']              = 'jcart/';

// Path to your checkout page
$config['checkoutPath']           = 'checkout.php';

// The HTML name attributes used in your item forms
$config['item']['id']             = 'my-item-id';    // Item id
$config['item']['name']           = 'my-item-name';    // Item name
$config['item']['price']          = 'my-item-price';    // Item price
$config['item']['qty']            = 'my-item-qty';    // Item quantity
$config['item']['url']            = 'my-item-url';    // Item URL (optional)
$config['item']['add']            = 'my-add-button';    // Add to cart button


////////////////////////////////////////////////////////////////////////////////
// OPTIONAL SETTINGS

// Three-letter currency code, defaults to USD if empty
// See available options here: http://j.mp/agNsTx
$config['currencyCode']           = '';

// Add a unique token to form posts to prevent CSRF exploits
// Learn more: http://conceptlogic.com/jcart/security.php
$config['csrfToken']              = false;

// Override default cart text
$config['text']['cartTitle']      = 'Carrinho de compra';    // Shopping Cart
$config['text']['singleItem']     = 'Item';    // Item
$config['text']['multipleItems']  = 'Itens';    // Items
$config['text']['subtotal']       = 'Sub total';    // Subtotal
$config['text']['update']         = 'atualizar';    // update
$config['text']['checkout']       = 'pagar';    // checkout
$config['text']['checkoutPaypal'] = 'Pagar com o Pagseguro';    // Checkout with PayPal
$config['text']['removeLink']     = 'remover';    // remove
$config['text']['emptyButton']    = 'vazio';    // empty
$config['text']['emptyMessage']   = 'Seu carrinho está vazio';    // Your cart is empty!
$config['text']['itemAdded']      = 'Item adicionado';    // Item added!
$config['text']['priceError']     = 'Inválido formato de preço';    // Invalid price format!
$config['text']['quantityError']  = '';    // Item quantities must be whole numbers!
$config['text']['checkoutError']  = '';    // Your order could not be processed!

// Override the default buttons by entering paths to your button images
$config['button']['checkout']     = '';
$config['button']['paypal']       = '';
$config['button']['update']       = '';
$config['button']['empty']        = '';


////////////////////////////////////////////////////////////////////////////////
// ADVANCED SETTINGS

// Display tooltip after the visitor adds an item to their cart?
$config['tooltip']                = true;

// Allow decimals in item quantities?
$config['decimalQtys']            = false;

// How many decimal places are allowed?
$config['decimalPlaces']          = 1;

// Number format for prices, see: http://php.net/manual/en/function.number-format.php
$config['priceFormat']            = array('decimals' => 2, 'dec_point' => '.', 'thousands_sep' => ',');

// Send visitor to PayPal via HTTPS?
$config['pagseguro']['https']        = true;


// The URL a visitor is returned to after completing their PayPal transaction
$config['pagseguro']['returnUrl']    = '';


?>