                    <div class="widget properties last">
					    <div class="title">
					        <h2>Novos cursos</h2>
					    </div><!-- /.title -->
					    <div class="content">
							<?php
								$arr = $c->Nova_venda($id = null, ID);
								for ($i = 0; $i < count($arr); $i++){
							?>					    
					        <div class="property">
					            <div class="image">
					                <a href="detalhe.php?id=<?=$arr[$i]->id['id']?>"></a>
					                <img src="<?=$arr[$i]->capa['capa']?>" width="100px" height="74px" alt="">
					            </div><!-- /.image -->
					
					            <div class="wrapper">
					                <div class="title">
					                    <h3>
					                        <a href="detalhe.php?id=<?=$arr[$i]->id['id']?>"><?=$arr[$i]->nome['nome']?></a>
					                    </h3>
					                </div><!-- /.title -->
					                <div class="location">
									<?php
										if($arr[$i]->pacote['pacote'] == false){
											$arre = $c->Venda_many($arr[$i]->id['id']);
											for ($j = 0; $j < count($arre); $j++){
									        	echo $arre[$j]->concursoNome['concursoNome'];
											}
										}else{
									        	echo "Mais de uma disciplina";					
										}
									?>						                
					                </div><!-- /.location -->
					                <div class="price">R$ <?=$arr[$i]->valor['valor']?></div><!-- /.price -->
					            </div><!-- /.wrapper -->
					        </div><!-- /.property -->
							<?php
								}
							?>
					    </div><!-- /.content -->
					</div><!-- /.properties -->