@import 'compass/css3/background-clip';
@import 'compass/css3/border-radius';
@import 'compass/css3/box-shadow';
@import 'compass/css3/box-sizing';
@import 'compass/css3/images';
@import 'compass/css3/text-shadow';
@import 'compass/css3/transition';


@import 'helpers/mixins';
@import 'helpers/forms';
@import 'helpers/elements';
@import 'helpers/header';
@import 'helpers/ezmark';
@import 'helpers/palette';
@import 'helpers/not_found';
@import 'helpers/list_your_property';
@import 'helpers/slider';
@import 'helpers/navigation';
@import 'helpers/properties';
@import 'helpers/propertydetail';
@import 'helpers/pricing';
@import 'helpers/login_register';
@import 'helpers/agents';
@import 'helpers/aboutus';
@import 'helpers/partners';
@import 'helpers/carousel'; 
@import 'helpers/map';
@import 'helpers/features';
@import 'helpers/bottom';
@import 'helpers/footer';


$font-family-default: 'Open Sans', 'Arial', sans-serif;


.btn { -webkit-font-smoothing: antialiased; @include background-image(none); @include border-radius(0px); @include box-shadow(none); @include text-shadow(none); border: 0px; padding: 7px 15px 7px 15px; font-weight: normal; 
  &.btn-primary { @include transition(background-color .2s ease-in); background-color: $blue;
    &.arrow-right { background-image: url('../img/arrow-right-white.png'); background-position: 90% center; background-repeat: no-repeat; background-size: 8px 11px; padding-right: 30px;
      @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
        background-image: url('../img/arrow-right-white@2x.png');
      }
    }
    &:hover { background-color: darken($blue, 10%); }
  }
  &.btn-large { padding: 11px 19px; 
    &.arrow-right { padding-right: 50px; }
  }
}

html { height: 100%; }
body { -webkit-font-smoothing: antialiased; background-color: $body-background-color; color: $body-text-color; font-family: $font-family-default; font-size: 14px; height: 100%; margin: 0px; padding: 0px;
  a { @include transition(color .1s ease-in); color: $body-link-color;
    &:hover { color: darken($body-link-color, 10%);  text-decoration: underline; }
  }
  p {
    line-height: 20px;
    &.content-icon-spacing { padding-left: 55px; }
  }
  hr {
    &.dotted { background-image: url('../img/border-gray.png'); background-position: left center; background-repeat: no-repeat; border: 0px; height: 1px; } 
  }
  ul {
    &.dotted {
      li { color: $blue-dark; list-style-position: outside; list-style-type: disc; margin-left: 20px;
        .inner { color: $black;
          strong { color: $black-dark; }
        }
      }
    }
  }
  #wrapper-outer { height: 100%;
    #wrapper { @include transition(left .3s ease-in); display: table; height: 100%; position: relative; width: 100%;
      #wrapper-inner { display: table-row; height: 100%; }
      #footer-wrapper { display: table-row; height: 1px; }
    }
  }
}

@media(min-width: 980px) {
  body {
    padding-top: 0px;
  }
}

@media (max-width: 979px) {
  body {
    &.nav-open {
      #wrapper-outer { overflow-x: hidden;
        #wrapper {  left: 70%; }
      }
    }
  }
}
#content { padding-bottom: 30px; }

@media (max-width: 767px) {
  #content { 
    #main {
      padding-left: 20px; padding-right: 20px;
    }
  }
}

h1.page-header,
h2.page-header { border: 0px; color: $body-heading-color; font-size: 30px; font-weight: 300; line-height: 40px; margin: 20px 0px; padding: 0px; }
h2 { color: $body-heading-color; font-size: 24px; font-weight: lighter; margin: 20px 0px; }
h3 { color: $body-heading-color; font-size: 18px; font-weight: normal;
  &.address { background-image: url('../img/icons/bubble-address.png'); background-position: left center; background-repeat: no-repeat; background-size: 34px 35px; padding-left: 55px; }
  &.call-us { background-image: url('../img/icons/bubble-call-us.png'); background-position: left center; background-repeat: no-repeat; background-size: 34px 35px; padding-left: 55px; }
  &.email { background-image: url('../img/icons/bubble-email.png'); background-position: left center; background-repeat: no-repeat; background-size: 34px 35px; padding-left: 55px; }
  @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
    &.address { background-image: url('../img/icons/bubble-address@2x.png'); }
    &.call-us { background-image: url('../img/icons/bubble-call-us@2x.png'); }
    &.email { background-image: url('../img/icons/bubble-email@2x.png'); }
  }
}

@media (max-width: 767px) {
  h1.page-header, h2.page-header { font-size: 24px; }
  h2 { font-size: 24px; }
}

body.green, body.gray-green {
  .marker {
    background-image: url('../img/markers/marker-green.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-green@2x.png');
    }
  }
}

body.green-light, body.gray-green-light {
  .marker {
    background-image: url('../img/markers/marker-green-light.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-green-light@2x.png');
    }
  }
}

body.brown, body.gray-brown {
  .marker {
    background-image: url('../img/markers/marker-brown.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-brown@2x.png');
    }
  }
}

body.brown-dark, body.gray-brown-dark {
  .marker {
    background-image: url('../img/markers/marker-brown-dark.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-brown-dark@2x.png');
    }
  }
}

body.turquiose, body.gray-turquiose {
  .marker {
    background-image: url('../img/markers/marker-turquiose.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-turquiose@2x.png');
    }
  }
}

body.orange, body.gray-orange {
  .marker {
    background-image: url('../img/markers/marker-orange.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-orange@2x.png');
    }
  }
}

body.magenta, body.gray-magenta {
  .marker {
    background-image: url('../img/markers/marker-magenta.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-magenta@2x.png');
    }
  }
}

body.red, body.gray-red {
  .marker {
    background-image: url('../img/markers/marker-red.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-red@2x.png');
    }
  }
}

body.violet, body.gray-violet {
  .marker {
    background-image: url('../img/markers/marker-violet.png');
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/markers/marker-violet@2x.png');
    }
  }
}

body.pattern-cloth-alike {
  #content { background-image: url('../img/patterns/large/cloth-alike.png'); background-repeat: repeat; background-size: 102px 78px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/cloth-alike@2x.png');
    }
  }
}

body.pattern-cloth-alike {
  #content { background-image: url('../img/patterns/large/cloth-alike.png'); background-repeat: repeat; background-size: 102px 78px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/cloth-alike@2x.png');
    }
  }
}

body.pattern-corrugation {
  #content { background-image: url('../img/patterns/large/corrugation.png'); background-repeat: repeat; background-size: 8px 5px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/corrugation@2x.png');
    }
  }
}

body.pattern-diagonal-noise {
  #content { background-image: url('../img/patterns/large/diagonal-noise.png'); background-repeat: repeat; background-size: 100px 100px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/diagonal-noise@2x.png');
    }
  }
}

body.pattern-dust {
  #content { background-image: url('../img/patterns/large/dust.png'); background-repeat: repeat; background-size: 400px 300px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/dust@2x.png');
    }
  }
}

body.pattern-fabric-plaid {
  #content { background-image: url('../img/patterns/large/fabric-plaid.png'); background-repeat: repeat; background-size: 102px 78px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/fabric-plaid@2x.png');
    }
  }
}

body.pattern-farmer {
  #content { background-image: url('../img/patterns/large/farmer.png'); background-repeat: repeat; background-size: 200px 200px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/farmer@2x.png');
    }
  }
}

body.pattern-grid-noise {
  #content { background-image: url('../img/patterns/large/grid-noise.png'); background-repeat: repeat; background-size: 98px 98px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/grid-noise@2x.png');
    }
  }
}

body.pattern-lightpaperfibers {
  #content { background-image: url('../img/patterns/large/lightpaperfibers.png'); background-repeat: repeat; background-size: 500px 300px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/lightpaperfibers@2x.png');
    }
  }
}

body.pattern-retina-wood {
  #content { background-image: url('../img/patterns/large/retina-wood.png'); background-repeat: repeat; background-size: 512px 512px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/retina-wood@2x.png');
    }
  }
}

body.pattern-lghtmesh {
  #content { background-image: url('../img/patterns/large/lghtmesh.png'); background-repeat: repeat; background-size: 256px 256px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/lghtmesh@2x.png');
    }
  }
}

body.pattern-pw-maze-white {
  #content { background-image: url('../img/patterns/large/pw-maze-white.png'); background-repeat: repeat; background-size: 46px 23px;
    @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
      background-image: url('../img/patterns/large/pw-maze-white@2x.png');
    }
  }
}

body.header-light {
  .breadcrumb-wrapper { background-color: $white; border-bottom: 1px solid $gray-lighter;
    span { color: $gray !important;  }
    .nav {
      li {
        a { border-right-color: $gray; color: $gray !important; }
      }
    }
  }
  #navigation { background-color: $blue-medium;
    input[type=text] { border: 0px !important; height: 22px; }
    button.btn { border: 0px; height: 34px; }
    .nav {
      .nolink, a { color: $white !important; }

      @media (min-width: 980px) {
        .menuparent {
          > .nolink,
          > a { background-image: url('../img/arrow-bottom-white.png') !important;
            @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
              background-image: url('../img/arrow-bottom-white@2x.png') !important;
            }
          }

          .menuparent {
            > .nolink,
            > a { background-image: url('../img/arrow-right-white.png') !important;
              @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
                background-image: url('../img/arrow-right-white@2x.png') !important;
              }
            }
          }
        }
      }
    }
  }
}

body.header-dark {
  .breadcrumb-wrapper { background-color: $blue-dark; border-bottom: 1px solid $blue-dark; }
  #header-inner { background-color: $blue-medium; color: #fff;
    .site-name {
      a { color: #fff !important; }
    }
    .site-phone {
      span { background-image: url("../img/icons/phone-white.png") !important; color: #fff !important;
        @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
          background-image: url("../img/icons/phone-white@2x.png") !important;
        }
      }
    }
    .site-email {
      a { background-image: url("../img/icons/mail.png") !important; color: #fff !important;
        @media (-webkit-min-device-pixel-ratio: 2), (-moz-min-device-pixel-ratio: 2) {
          background-image: url("../img/icons/mail@2x.png") !important;
        }
      }
    }
  }
}

