	<form method="post" action="" class="jcart" style="float:right">
		<fieldset>
			<input type="hidden" name="jcartToken" value="<?php echo $_SESSION['jcartToken'];?>" />
			<input type="hidden" name="my-item-id" value="<?=$arr[$i]->id['id']?>" />
			<input type="hidden" name="my-item-qty" value="1" />			
			<input type="hidden" name="my-item-name" value="<?=$arr[$i]->nome['nome']?>" />
			<input type="hidden" name="my-item-price" value="<?=$arr[$i]->valor['valor']?>" />
			<input type="hidden" name="my-item-url" value="<?=$_SERVER['PHP_SELF']?>?id=<?=$arr[$i]->id['id']?>" />										
			<input type="submit" name="my-add-button" style="width: 152px; height: 31px; color: darkolivegreen; font-size: 14px;" value="Comprar" class="button tip" />
		</fieldset>
	</form> 				
