<?php

class Aluno{

	public $idaluno;
	public $nome;
	public $cpf;
	public $email;
	public $senha;
	public $tel;
	public $cel;	
	public $endereco;
	public $complemento;
	public $cep;
	public $bairro;	
	public $cidade;
	public $estado;
	public $cliente_idcliente;	

	protected function setidaluno($idaluno){
		$this->idaluno = $idaluno;
	}

	protected function setnome($nome){
		$this->nome = $nome;
	}

	protected function setcpf($cpf){
		$this->cpf = $cpf;
	}

	protected function setemail($email){
		$this->email = $email;
	}

	protected function setsenha($senha){
		$this->senha = $senha;
	}

	protected function settel($tel){
		$this->tel = $tel;
	}	

	protected function setcel($cel){
		$this->cel = $cel;
	}		
	
	protected function setendereco($endereco){
		$this->endereco = $endereco;
	}

	protected function setcomplemento($complemento){
		$this->complemento = $complemento;
	}
	
	protected function setbairro($bairro){
		$this->bairro = $bairro;
	}

	protected function setcep($cep){
		$this->cep = $cep;
	}

	protected function setcidade($cidade){
		$this->cidade = $cidade;
	}

	protected function setestado($estado){
		$this->estado = $estado;
	}	
	
	protected function setcliente_idcliente($cliente_idcliente){
		$this->cliente_idcliente = $cliente_idcliente;
	}		

	public function all($id, $cliente){

	$arr = array();	
		
	$sql = "SELECT `idaluno`, `nome`, `email`, `senha`, `cpf`, `tel`, `cel`, `endereco`, `complemento`, `bairro`, `cep`, `cidade`, `estado`, `cliente_idcliente` FROM `aluno` WHERE `idaluno` = $id;";
	$vai = new MySQLDB();
	$result = $vai->executeQuery($sql);
	
	while($dados = mysql_fetch_array($result)){
		$cliente = new Aluno();
		$cliente->setidaluno(array('idaluno' => $dados['idaluno']));
		$cliente->setnome(array('nome' => $dados['nome']));
		$cliente->setcpf(array('cpf' => $dados['cpf']));
		$cliente->setemail(array('email' => $dados['email']));
		$cliente->setsenha(array('senha' => $dados['senha']));
		$cliente->settel(array('tel' => $dados['tel']));
		$cliente->setcel(array('cel' => $dados['cel']));		
		$cliente->setendereco(array('endereco' => $dados['endereco']));
		$cliente->setcomplemento(array('complemento' => $dados['complemento']));
		$cliente->setbairro(array('bairro' => $dados['bairro']));
		$cliente->setcep(array('cep' => $dados['cep']));
		$cliente->setcidade(array('cidade' => $dados['cidade']));
		$cliente->setestado(array('estado' => $dados['estado']));
		$cliente->setcliente_idcliente(array('cliente_idcliente' => $dados['cliente_idcliente']));		
		$arr[] = $cliente;
	}
	return $arr;
	}	

	public function Cad($nome, $cpf, $email, $senha, $tel, $cel, $cliente_idcliente){

		$sql = "INSERT INTO `aluno` (`nome`, `cpf`, `email`, `senha`, `tel`, `cel`, `cliente_idcliente`) VALUES ('$nome', '$cpf', '$email', '$senha', '$tel', '$cel', $cliente_idcliente);";
		$vai = new MySQLDB();
		$vai->executeQuery($sql);
		
		$id = mysql_insert_id();
		
		$_SESSION['idAluno'] = $id;
		$_SESSION['emailAluno'] = "$email";
		$_SESSION['nomeAluno'] = "$nome";	
		$_SESSION['cpfAluno'] = "$cpf";				
		$_SESSION['telAluno'] = "$tel";									
		
		header ("Location: checkout.php");
	}		
	
}

class login extends Aluno {

	public function verificaLogin($email, $password){

		$vai = new MySQLDB();
		$email = stripslashes($email);
		$password = stripslashes($password);
		$email = mysql_real_escape_string($email);
		$password = mysql_real_escape_string($password);


		$sql = "SELECT `senha` FROM `aluno` WHERE `email`='$email';";
		$result = $vai->ExecuteQuery($sql);

		while ($rows = mysql_fetch_object($result)) {
			$pass = $rows->senha;
		}
		if ($pass == "") {
			header ("Location: login.php?vi=erro_login");
		}else{

			include("../../plugins/Password/PASSWORD.php");
			$senha = PASSWORD::check_password($pass, $password);

			if($senha){
				$sql = "SELECT * FROM `aluno` WHERE `email`='$email';";
				$result = $vai->ExecuteQuery($sql);

				while ($rows = mysql_fetch_object($result)) {
					$id = $rows->idaluno;
					$email = $rows->email;
					$nome = $rows->nome;
					$cpf = $rows->cpf;
					$tel = $rows->tel;
				}
				session_start();
				$_SESSION['idAluno'] = $id;
				$_SESSION['emailAluno'] = "$email";
				$_SESSION['nomeAluno'] = "$nome";
				$_SESSION['cpfAluno'] = "$cpf";				
				$_SESSION['telAluno'] = "$tel";								
				$result = $vai->ExecuteQuery($sql2);
				header ("Location: checkout.php");
			}else{
				header ("Location: login.php?vi=erro");
			}

		}
	}
}

?>